NotificationAnalytics class abstract interface

Optional analytics adapter (Firebase Analytics, Mixpanel, or custom).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

actionExecuted(NotificationActionEvent event) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notificationDismissed(NotificationEvent event) Future<void>
notificationDisplayed(NotificationEvent event) Future<void>
notificationReceived(NotificationEvent event) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited