NotificationChannel class abstract

Cross-platform channel configuration.

iOS ignores Android-only channel properties and uses categoryId.

Available extensions
Annotations
  • @freezed

Constructors

NotificationChannel({required String id, required String name, @Default.new('') String description, @Default.new(ChannelImportance.defaultImportance) ChannelImportance importance, @Default.new(true) bool playSound, @Default.new(true) bool enableVibration, @Default.new(true) bool showBadge, String? sound, String? categoryId})
const
factory
NotificationChannel.fromJson(Map<String, Object?> json)
factory

Properties

categoryId String?
no setterinherited
copyWith → $NotificationChannelCopyWith<NotificationChannel>
Create a copy of NotificationChannel with the given fields replaced by the non-null parameter values.
no setterinherited
description String
no setterinherited
enableVibration bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
importance ChannelImportance
no setterinherited
name String
no setterinherited
playSound bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBadge bool
no setterinherited
sound String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_NotificationChannel value)) → TResult

Available on NotificationChannel, provided by the NotificationChannelPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_NotificationChannel value)?) → TResult?

Available on NotificationChannel, provided by the NotificationChannelPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_NotificationChannel value)?, {required TResult orElse()}) → TResult

Available on NotificationChannel, provided by the NotificationChannelPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String name, String description, ChannelImportance importance, bool playSound, bool enableVibration, bool showBadge, String? sound, String? categoryId)?, {required TResult orElse()}) → TResult

Available on NotificationChannel, provided by the NotificationChannelPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this NotificationChannel to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String name, String description, ChannelImportance importance, bool playSound, bool enableVibration, bool showBadge, String? sound, String? categoryId)) → TResult

Available on NotificationChannel, provided by the NotificationChannelPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String name, String description, ChannelImportance importance, bool playSound, bool enableVibration, bool showBadge, String? sound, String? categoryId)?) → TResult?

Available on NotificationChannel, provided by the NotificationChannelPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited