NotificationMessagePatterns extension

Adds pattern-matching-related methods to NotificationMessage.

on

Methods

map<TResult extends Object?>(TResult $default(_NotificationMessage value)) → TResult

Available on NotificationMessage, provided by the NotificationMessagePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_NotificationMessage value)?) → TResult?

Available on NotificationMessage, provided by the NotificationMessagePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_NotificationMessage value)?, {required TResult orElse()}) → TResult

Available on NotificationMessage, provided by the NotificationMessagePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int notificationId, String messageId, String? title, String? body, String? imageUrl, Map<String, Object?> data, List<NotificationAction> actions, String channelId, String? categoryId, String? routeType, String? deepLink, DateTime? sentAt, String? topic, String? collapseKey, bool silent, Map<String, Object?> rawJson)?, {required TResult orElse()}) → TResult

Available on NotificationMessage, provided by the NotificationMessagePatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(int notificationId, String messageId, String? title, String? body, String? imageUrl, Map<String, Object?> data, List<NotificationAction> actions, String channelId, String? categoryId, String? routeType, String? deepLink, DateTime? sentAt, String? topic, String? collapseKey, bool silent, Map<String, Object?> rawJson)) → TResult

Available on NotificationMessage, provided by the NotificationMessagePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int notificationId, String messageId, String? title, String? body, String? imageUrl, Map<String, Object?> data, List<NotificationAction> actions, String channelId, String? categoryId, String? routeType, String? deepLink, DateTime? sentAt, String? topic, String? collapseKey, bool silent, Map<String, Object?> rawJson)?) → TResult?

Available on NotificationMessage, provided by the NotificationMessagePatterns extension

A variant of when that fallback to returning null