ActionRegistry class final

In-memory registry owned by an FcmActionsClient instance.

Constructors

ActionRegistry()

Properties

actions UnmodifiableMapView<String, NotificationAction>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
find(String id) NotificationAction?
handlerFor(String id) NotificationActionCallback?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(NotificationAction action, {NotificationActionCallback? handler}) → void
registerAll(Iterable<NotificationAction> actions) → void
registerHandler(String actionId, NotificationActionCallback handler) → void
toString() String
A string representation of this object.
inherited
unregister(String id) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited