ChannelRegistry class final

Constructors

ChannelRegistry()

Properties

channels UnmodifiableMapView<String, NotificationChannel>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

find(String id) NotificationChannel?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(NotificationChannel channel) → void
registerAll(Iterable<NotificationChannel> channels) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited