MessagingGateway class abstract interface

Properties

foregroundMessages Stream<RemoteMessage>
no setter
hashCode int
The hash code for this object.
no setterinherited
openedMessages Stream<RemoteMessage>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configureForegroundPresentation() Future<void>
getInitialMessage() Future<RemoteMessage?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerBackgroundHandler() → void
requestPermission() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited