NotificationNavigator class final

Named-route navigation without application switch statements.

Constructors

NotificationNavigator({required GlobalKey<NavigatorState>? navigatorKey, Iterable<RouteMapper> routes = const <RouteMapper>[]})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(RouteMapper mapper) → void
registerAll(Iterable<RouteMapper> routes) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited