NotificationParser class final

Converts FCM's platform-specific shape into a validated package model.

Constructors

NotificationParser({required int maxPayloadBytes, required String defaultChannelId, required ActionResolver resolveAction})
const

Properties

defaultChannelId String
final
hashCode int
The hash code for this object.
no setterinherited
maxPayloadBytes int
final
resolveAction ActionResolver
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseMap(Map<String, Object?> input, {Map<String, Object?>? rawJson}) NotificationMessage
parseRemoteMessage(RemoteMessage remote) NotificationMessage
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited