PlatformNotificationResponse class final

Constructors

PlatformNotificationResponse({required int? notificationId, required String? payload, required String? actionId, required String? input, required bool dismissed, required bool launchedApp, required bool fromBackground})
const

Properties

actionId String?
final
dismissed bool
final
fromBackground bool
final
hashCode int
The hash code for this object.
no setterinherited
input String?
final
launchedApp bool
final
notificationId int?
final
payload String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited