ReplayGuard class final

Persists recently processed action identities to suppress duplicate/replayed platform callbacks across process restarts.

Constructors

ReplayGuard({SharedPreferencesAsync? preferences, required Duration window})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
window Duration
final

Methods

claim(String identity, DateTime now) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited