NotificationEvent class abstract
Emitted whenever a notification is received, displayed, opened, or removed.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
NotificationEvent({required NotificationMessage message, required DateTime timestamp, required NotificationPlatform platform, required NotificationState state, NotificationInteraction? interaction, @Default.new(<String, Object?>{}) Map<
String, Object?> rawJson}) -
constfactory
-
NotificationEvent.fromJson(Map<
String, Object?> json) -
factory
Properties
-
copyWith
→ $NotificationEventCopyWith<
NotificationEvent> -
Create a copy of NotificationEvent
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- interaction → NotificationInteraction?
-
no setterinherited
- message → NotificationMessage
-
no setterinherited
- platform → NotificationPlatform
-
no setterinherited
-
rawJson
→ Map<
String, Object?> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → NotificationState
-
no setterinherited
- timestamp → DateTime
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_NotificationEvent value)) → TResult -
Available on NotificationEvent, provided by the NotificationEventPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_NotificationEvent value)?) → TResult? -
Available on NotificationEvent, provided by the NotificationEventPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_NotificationEvent value)?, {required TResult orElse()}) → TResult -
Available on NotificationEvent, provided by the NotificationEventPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(NotificationMessage message, DateTime timestamp, NotificationPlatform platform, NotificationState state, NotificationInteraction? interaction, Map< String, Object?> rawJson)?, {required TResult orElse()}) → TResult -
Available on NotificationEvent, provided by the NotificationEventPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this NotificationEvent to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(NotificationMessage message, DateTime timestamp, NotificationPlatform platform, NotificationState state, NotificationInteraction? interaction, Map< String, Object?> rawJson)) → TResult -
Available on NotificationEvent, provided by the NotificationEventPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(NotificationMessage message, DateTime timestamp, NotificationPlatform platform, NotificationState state, NotificationInteraction? interaction, Map< String, Object?> rawJson)?) → TResult? -
Available on NotificationEvent, provided by the NotificationEventPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited