ActionQueue class final
Durable failed-action queue. It is intentionally transport agnostic: authentication/network middleware can throw and the action is retried when the app resumes or drain is called explicitly.
Constructors
- ActionQueue({SharedPreferencesAsync? preferences, required int maxRetries})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxRetries → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
count(
) → Future< int> -
drain(
QueuedActionExecutor execute) → Future< void> -
enqueue(
NotificationActionEvent event) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited