FcmActionsEventBus class final

Typed broadcast streams for package events.

Constructors

FcmActionsEventBus()

Properties

hashCode int
The hash code for this object.
no setterinherited
onAction Stream<NotificationActionEvent>
no setter
onBackgroundMessage Stream<NotificationEvent>
no setter
onDismiss Stream<NotificationEvent>
no setter
onForegroundMessage Stream<NotificationEvent>
no setter
onNotification Stream<NotificationEvent>
no setter
onOpenedApp Stream<NotificationEvent>
no setter
onReply Stream<NotificationActionEvent>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

action(NotificationActionEvent event) → void
background(NotificationEvent event) → void
dismissal(NotificationEvent event) → void
dispose() Future<void>
foreground(NotificationEvent event) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notification(NotificationEvent event) → void
opened(NotificationEvent event) → void
reply(NotificationActionEvent event) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited