Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
int id) → Future< void> -
cancelAll(
) → Future< void> -
createChannels(
Iterable< NotificationChannel> channels) → Future<void> -
initialize(
{required String defaultAndroidIcon, required bool requestPermission, required List< NotificationMessage> categoryTemplates, required PlatformNotificationResponseCallback onResponse}) → Future<PlatformNotificationResponse?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerCategories(
Iterable< NotificationMessage> templates) → Future<void> -
show(
NotificationMessage message, NotificationChannel channel) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited